==> live-usb-maker-gui-antix_0.1.10.tar.xz: live-usb-maker-gui-antix/translations/live-usb-maker-gui-antix_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="33"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Choix du périphérique USB cible&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="43"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Choix du fichier ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="88"/>
        <location filename="mainwindow.cpp" line="446"/>
        <location filename="mainwindow.cpp" line="464"/>
        <source>Select ISO</source>
        <translation>Choisir une image ISO</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="100"/>
        <source>Refresh drive list</source>
        <translation>Rafraîchir la liste des lecteurs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="112"/>
        <location filename="mainwindow.cpp" line="393"/>
        <location filename="mainwindow.cpp" line="399"/>
        <source>Show advanced options</source>
        <translation>Afficher les options avancées</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="130"/>
        <source>Advanced Options</source>
        <translation>Options avancées</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="139"/>
        <source>Verbosity (less to more):</source>
        <translation>Verbosité (du moins au plus):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="190"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Taille de la partition ESP (uefi):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="222"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Créer le système de fichiers ext4 même s&apos;il en existe déjà un</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="229"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Conserver le répertoire boot originel lors de la mise à jour du live-usb</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="236"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Utilise le partitionnement gpt à la place de msdos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="239"/>
        <source>GPT partitioning</source>
        <translation>Partitionnement GPT</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="246"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Mettre à jour (met uniquement à jour un live-usb existant)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="253"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Ne pas remplacer les fichiers syslinux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="256"/>
        <source>Keep syslinux files</source>
        <translation>Conserver les fichiers syslinux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="263"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorer les vérifications USB/Démontable</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="270"/>
        <source>Temporarily disable automounting</source>
        <translation>Désactiver temporairement le montage automatique</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="280"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Activer le marqueur pmbr_boot sur le disque (pas de démarrage via UEFI)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="293"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="308"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Ne pas lancer de commande affectant le périphérique usb</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="311"/>
        <source>Dry run (no change to system)</source>
        <translation>Test (aucune modification du système)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="318"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>Cloner à partir d&apos;un usb-live monté ou d&apos;un fichier iso</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="321"/>
        <source>Clone an existing live system</source>
        <translation>Cloner un système live existant</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="328"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Organise le démarrage depuis une partition chiffrée. Exigera une phrase de passe au premier démarrage.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="331"/>
        <source>Encrypt</source>
        <translation>Chiffrer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="338"/>
        <source>Clone running live system</source>
        <translation>Cloner un système live en fonctionnement</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="345"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Lecture seule, incompatible avec la persistance</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <source>Copy image to USB (dd)</source>
        <translation>Copier une image vers un USB (dd)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="371"/>
        <source>Percent of USB-device to use:</source>
        <translation>Part du périphérique USB utiisé (%):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="394"/>
        <source>Label ext partition:</source>
        <translation>Etiquette de la partition</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="442"/>
        <source>For distros other than antiX/MX use &quot;Copy image to USB (dd)&quot; only.</source>
        <translation>Pour les distributions différentes de antiX/MX se servir uniquement de &quot;Copier une image sur un périphérique USB (dd)&quot;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="499"/>
        <source>Quit application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="502"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="510"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="542"/>
        <source>Display help </source>
        <translation>Afficher l&apos;aide</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="545"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="553"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="569"/>
        <source>Back</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="628"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="655"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="658"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="666"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="72"/>
        <location filename="mainwindow.cpp" line="239"/>
        <location filename="mainwindow.cpp" line="379"/>
        <source>Failure</source>
        <translation>Échec</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="72"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>La source est la destination sont sur le même périphérique, veuillez recommencer la sélection.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="94"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Ecriture de %1 à l&apos;aide de &apos;dd&apos; vers /dev/%2,

Veuillez attendre la fin du processus</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="237"/>
        <source>Success</source>
        <translation>Réussite de l&apos;installation</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="237"/>
        <source>LiveUSB creation successful!</source>
        <translation>Création du Live USB accomplie!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="239"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Erreurs rencontrées pendant le processus de création du Live USB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <source>Please select a USB device to write to</source>
        <translation>Veuillez choisir le périphérique USB sur lequel écrire</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="288"/>
        <location filename="mainwindow.cpp" line="458"/>
        <source>clone</source>
        <translation>clone</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="328"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="329"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programme de création d&apos;un live-usb à partir d&apos;un fichier ISO, d&apos;un autre live-usb, d&apos;un live-cd/dvd ou d&apos;un système live en fonctionnement.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="331"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="332"/>
        <location filename="mainwindow.cpp" line="338"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="333"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="368"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Choisir le fichier ISO qui sera gravé sur le périphérique USB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="374"/>
        <location filename="mainwindow.cpp" line="442"/>
        <source>Select Source Directory</source>
        <translation>Choix du répertoire source</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="379"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Impossible de trouver le fichier %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="395"/>
        <source>Hide advanced options</source>
        <translation>Cacher les options avancées</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="441"/>
        <location filename="mainwindow.cpp" line="456"/>
        <source>Select Source</source>
        <translation>Choisir la source</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="445"/>
        <location filename="mainwindow.cpp" line="462"/>
        <source>Select ISO file</source>
        <translation>Choisir le fichier ISO</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="52"/>
        <source>You must run this program as root.</source>
        <translation>Vous devez lancer cette application avec les droits administrateur.</translation>
    </message>
</context>
</TS>

==> live-usb-maker-gui-antix_0.2.17.tar.xz: live-usb-maker-gui-antix/translations/live-usb-maker-gui-antix_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fr" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_Name</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="56"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="88"/>
        <source>Display help </source>
        <translation>Afficher l&apos;aide</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="91"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="98"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="114"/>
        <source>Back</source>
        <translation>Précédent</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="172"/>
        <source>Next</source>
        <translation>Suivant</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="198"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="201"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="208"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="239"/>
        <location filename="mainwindow.cpp" line="462"/>
        <location filename="mainwindow.cpp" line="481"/>
        <source>Select ISO</source>
        <translation>Choisir une image ISO</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="250"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Choix du périphérique USB cible&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="260"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Choix du fichier ISO&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="289"/>
        <source>Advanced Options</source>
        <translation>Options avancées</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="307"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Créer le système de fichiers ext4 même s&apos;il en existe déjà un</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="314"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Conserver le répertoire boot originel lors de la mise à jour du live-usb</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="321"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Utilise le partitionnement gpt à la place de msdos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="324"/>
        <source>GPT partitioning</source>
        <translation>Partitionnement GPT</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="331"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Mettre à jour (met uniquement à jour un live-usb existant)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="338"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Ne pas remplacer les fichiers syslinux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="341"/>
        <source>Keep syslinux files</source>
        <translation>Conserver les fichiers syslinux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorer les vérifications USB/Démontable</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="355"/>
        <source>Temporarily disable automounting</source>
        <translation>Désactiver temporairement le montage automatique</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="365"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Activer le marqueur pmbr_boot sur le disque (pas de démarrage via UEFI)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="372"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>N&apos;utilisez pas fuseiso pour monter des images iso</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="398"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Taille de la partition ESP (uefi):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="418"/>
        <source>Verbosity (less to more):</source>
        <translation>Verbosité (du moins au plus):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="457"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="462"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="467"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="472"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="493"/>
        <source>Make separate data partition (percent)</source>
        <translation>Créer une partition de données séparée (pourcent) </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="500"/>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="510"/>
        <source>Refresh drive list</source>
        <translation>Rafraîchir la liste des lecteurs</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="524"/>
        <location filename="mainwindow.cpp" line="407"/>
        <source>Show advanced options</source>
        <translation>Afficher les options avancées</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="544"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="559"/>
        <source>Full-featured mode - writable LiveUSB</source>
        <translation>Mode complet - LiveUSB inscriptible</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="569"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Lecture seule, incompatible avec la persistance</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="572"/>
        <source>Image mode - read-only LiveUSB (dd)</source>
        <translation>Mode image - LiveUSB en lecture seule (dd)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="586"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Pour une distribution autre que antiX/MX, utilisez le mode image (dd).</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="634"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="669"/>
        <source>Percent of USB-device to use:</source>
        <translation>Part du périphérique USB utiisé (%):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="676"/>
        <source>Label ext partition:</source>
        <translation>Etiquette de la partition</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="724"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Ne pas lancer de commande affectant le périphérique usb</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="727"/>
        <source>Dry run (no change to system)</source>
        <translation>Test (aucune modification du système)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="734"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>Cloner à partir d&apos;un usb-live monté ou d&apos;un fichier iso</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="737"/>
        <source>Clone an existing live system</source>
        <translation>Cloner un système live existant</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="744"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Organise le démarrage depuis une partition chiffrée. Exigera une phrase de passe au premier démarrage.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="747"/>
        <source>Encrypt</source>
        <translation>Chiffrer</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="754"/>
        <source>Clone running live system</source>
        <translation>Cloner un système live en fonctionnement</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <location filename="mainwindow.cpp" line="267"/>
        <location filename="mainwindow.cpp" line="392"/>
        <source>Failure</source>
        <translation>Échec</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>La source est la destination sont sur le même périphérique, veuillez recommencer la sélection.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="111"/>
        <source>Writing %1 using 'dd' command to /dev/%2,

Please wait until the the process is completed</source>
        <translation>Ecriture de %1 à l&apos;aide de &apos;dd&apos; vers /dev/%2,

Veuillez attendre la fin du processus</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="265"/>
        <source>Success</source>
        <translation>Réussite de l&apos;installation</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="265"/>
        <source>LiveUSB creation successful!</source>
        <translation>Création du Live USB accomplie!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="267"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Erreurs rencontrées pendant le processus de création du Live USB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="316"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="316"/>
        <source>Please select a USB device to write to</source>
        <translation>Veuillez choisir le périphérique USB sur lequel écrire</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="319"/>
        <location filename="mainwindow.cpp" line="475"/>
        <source>clone</source>
        <translation>clone</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="355"/>
        <source>About %1</source>
        <translation>À propos %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="356"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="357"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Programme de création d&apos;un live-usb à partir d&apos;un fichier ISO, d&apos;un autre live-usb, d&apos;un live-cd/dvd ou d&apos;un système live en fonctionnement.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="359"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="360"/>
        <source>%1 License</source>
        <translation>%1 Licence</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="368"/>
        <source>%1 Help</source>
        <translation>%1 Aide</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="379"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Choisir le fichier ISO qui sera gravé sur le périphérique USB</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="387"/>
        <location filename="mainwindow.cpp" line="458"/>
        <source>Select Source Directory</source>
        <translation>Choix du répertoire source</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="392"/>
        <source>Could not find %1/antiX/linuxfs file</source>
        <translation>Impossible de trouver le fichier %1/antiX/linuxfs</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="413"/>
        <source>Hide advanced options</source>
        <translation>Cacher les options avancées</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="457"/>
        <location filename="mainwindow.cpp" line="473"/>
        <source>Select Source</source>
        <translation>Choisir la source</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="461"/>
        <location filename="mainwindow.cpp" line="479"/>
        <source>Select ISO file</source>
        <translation>Choisir le fichier ISO</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="about.cpp" line="32"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="about.cpp" line="33"/>
        <location filename="about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="main.cpp" line="75"/>
        <source>You must run this program as root.</source>
        <translation>Vous devez lancer cette application avec les droits administrateur.</translation>
    </message>
</context>
</TS>
